import React from 'react';
import Tag from '../Tag';
import { render } from "@testing-library/react";
describe('Tag component', () => {
  const size = ['small', 'medium'];
  const palette = ['default', 'danger', 'secondary', 'pureDotted', 'primaryDotted', 'dark', 'pureDarkDotted', 'darkPrimaryDotted', 'defaultLink'];
  const closePalette = ['danger', 'primary'];
  test('Should be render with the basic set of default props', () => {
    const {
      asFragment
    } = render( /*#__PURE__*/React.createElement(Tag, null));
    expect(asFragment()).toMatchSnapshot();
  });
  test('Should be render imageURL and hasAvatar', () => {
    const {
      asFragment
    } = render( /*#__PURE__*/React.createElement(Tag, {
      hasAvatar: true,
      imageURL: "https://www.w3schools.com/images/w3schools_green.jpg"
    }));
    expect(asFragment()).toMatchSnapshot();
  });
  test('Should be render text', () => {
    const {
      asFragment
    } = render( /*#__PURE__*/React.createElement(Tag, {
      text: "TagTest"
    }));
    expect(asFragment()).toMatchSnapshot();
  });
  test('Should be render initial', () => {
    const {
      asFragment
    } = render( /*#__PURE__*/React.createElement(Tag, {
      hasAvatar: true,
      initial: "avatarIntial"
    }));
    expect(asFragment()).toMatchSnapshot();
  });
  test.each(size)('Should render size  - %s', size => {
    const {
      asFragment
    } = render( /*#__PURE__*/React.createElement(Tag, {
      size: size
    }));
    expect(asFragment()).toMatchSnapshot();
  });
  test.each(size)('Should render onRemove - %s', size => {
    const mockOnRemove = jest.fn();
    const {
      asFragment
    } = render( /*#__PURE__*/React.createElement(Tag, {
      active: true,
      size: size,
      onRemove: mockOnRemove
    }));
    expect(asFragment()).toMatchSnapshot();
  });
  size.map(sz => {
    closePalette.map(cp => {
      test.each(palette)(`Should render active - palette %s, size ${sz} , closePalette ${cp}`, palette => {
        const mockOnRemove = jest.fn();
        const {
          asFragment
        } = render( /*#__PURE__*/React.createElement(Tag, {
          active: true,
          size: sz,
          palette: palette,
          onRemove: mockOnRemove,
          closePalette: cp
        }));
        expect(asFragment()).toMatchSnapshot();
      });
    });
  });
  test('Should be render rounded is false', () => {
    const mockOnRemove = jest.fn();
    const {
      asFragment
    } = render( /*#__PURE__*/React.createElement(Tag, {
      onRemove: mockOnRemove,
      rounded: false
    }));
    expect(asFragment()).toMatchSnapshot();
  });
  test.each(palette)('Should render palette - %s', palette => {
    const {
      asFragment
    } = render( /*#__PURE__*/React.createElement(Tag, {
      hasAvatar: true,
      active: true,
      palette: palette
    }));
    expect(asFragment()).toMatchSnapshot();
  });
  test('Should be render disabled is true', () => {
    const {
      asFragment
    } = render( /*#__PURE__*/React.createElement(Tag, {
      disabled: true
    }));
    expect(asFragment()).toMatchSnapshot();
  });
  test('Should be render disabled is false', () => {
    const {
      asFragment
    } = render( /*#__PURE__*/React.createElement(Tag, {
      disabled: false
    }));
    expect(asFragment()).toMatchSnapshot();
  });
  test.each(closePalette)('Should render closePalette - %s', closePalette => {
    const mockOnRemove = jest.fn();
    const {
      asFragment
    } = render( /*#__PURE__*/React.createElement(Tag, {
      onRemove: mockOnRemove,
      active: true,
      closePalette: closePalette
    }));
    expect(asFragment()).toMatchSnapshot();
  });
  test('Should be render onSelectTag', () => {
    const mockonSelectTag = jest.fn();
    const {
      asFragment
    } = render( /*#__PURE__*/React.createElement(Tag, {
      onSelectTag: mockonSelectTag
    }));
    expect(asFragment()).toMatchSnapshot();
  });
  test('Should be render closeTitle', () => {
    const mockOnRemove = jest.fn();
    const {
      asFragment
    } = render( /*#__PURE__*/React.createElement(Tag, {
      onRemove: mockOnRemove,
      closeTitle: "TagCloseTitle"
    }));
    expect(asFragment()).toMatchSnapshot();
  });
  test('Should be render dataId when active if false', () => {
    const mockOnRemove = jest.fn();
    const {
      asFragment
    } = render( /*#__PURE__*/React.createElement(Tag, {
      onRemove: mockOnRemove,
      dataId: "TagdataId"
    }));
    expect(asFragment()).toMatchSnapshot();
  });
  test('Should be render dataId when active if true', () => {
    const mockOnRemove = jest.fn();
    const {
      asFragment
    } = render( /*#__PURE__*/React.createElement(Tag, {
      active: true,
      onRemove: mockOnRemove,
      dataId: "TagdataId"
    }));
    expect(asFragment()).toMatchSnapshot();
  });
  test('Should be render iconName and iconSize', () => {
    const {
      asFragment
    } = render( /*#__PURE__*/React.createElement(Tag, {
      iconName: "ZD-androidd",
      iconSize: "15"
    }));
    expect(asFragment()).toMatchSnapshot();
  });
  test('Should be render tooltip', () => {
    const {
      asFragment
    } = render( /*#__PURE__*/React.createElement(Tag, {
      tooltip: "Tagtooltip"
    }));
    expect(asFragment()).toMatchSnapshot();
  });
  test.each(palette)('Should render avatarPalette - %s', palette => {
    const {
      asFragment
    } = render( /*#__PURE__*/React.createElement(Tag, {
      hasAvatar: true,
      palette: palette,
      avatarPalette: "primary"
    }));
    expect(asFragment()).toMatchSnapshot();
  });
  test('Should be render needEffect is false', () => {
    const {
      asFragment
    } = render( /*#__PURE__*/React.createElement(Tag, {
      needEffect: false
    }));
    expect(asFragment()).toMatchSnapshot();
  });
  test('Should be render isReadOnly is true', () => {
    const {
      asFragment
    } = render( /*#__PURE__*/React.createElement(Tag, {
      isReadOnly: true
    }));
    expect(asFragment()).toMatchSnapshot();
  });
  test('rendering the Custom class', () => {
    const mockOnRemove = jest.fn();
    const {
      asFragment
    } = render( /*#__PURE__*/React.createElement(Tag, {
      onRemove: mockOnRemove,
      iconName: "ZD-androidd",
      hasAvatar: true,
      customClass: {
        customTag: 'customCustomTag',
        customTagClose: 'customCustomTagClose',
        customTagIcon: 'customCustomTagIcon',
        customAvatar: 'customCustomAvatar'
      }
    }));
    expect(asFragment()).toMatchSnapshot();
  });
  test('rendering ally clearLabel', () => {
    const mockOnRemove = jest.fn();
    const {
      asFragment
    } = render( /*#__PURE__*/React.createElement(Tag, {
      onRemove: mockOnRemove,
      a11y: {
        clearLabel: 'TagClearLabel'
      }
    }));
    expect(asFragment()).toMatchSnapshot();
  });
});